@@ -17,11 +17,7 @@
 #     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 from django.core.management.base import BaseCommand
-from django.conf import settings
-from django.db import connection
-import logging
 from ... import util
-from ... import pgcommands
 
 
 class Command(BaseCommand):
@@ -33,14 +29,4 @@ class Command(BaseCommand):
         """
         Create all indexes
         """
-        paths = util.get_app_paths(settings)
-        # loop on apps
-        for path in paths:
-            # loop in indexex
-            for index in util.list_indexes_drop(path):
-                # do not try to drop non existing index
-                if pgcommands.index_exists(index):
-                    logging.info("Will drop %s" % index['name'])
-                    pgcommands.drop_index(index)
-                    logging.info("%s dropped" % index['name'])
-
+        util.command_drop()
